#!/bin/bash

if [ ! -r /etc/vdr/scripts/tools.inc ]; then
  echo "Error reading tools include"
  exit 10
else 
  . /etc/vdr/scripts/tools.inc
fi

init
VESAMODE=$(grep vga=0x /boot/grub/menu.lst | awk -F "vga=" '{ print $2 }' | awk -F" " '{ print $1 }')
CHANNELSCONF="$(ls -l /etc/vdr/channels.conf 2>/dev/null | awk -F "-> " '{ print $2 }')"

if [ -r /usr/bin/activysetup.sh ]; then
  . /usr/bin/activysetup.sh
fi

# <-------------- Dialoge ---------------->

function selectDAAPD
{
  START_DAAPD=$(getConfig "START_DAAPD")
  dialog --ok-label $(gettext "OK") --no-cancel --menu "$(gettext setup "selectDAAPD")" 10 30 2 ON "$(gettext setup "DAAPDON")" OFF "$(gettext setup "DAAPDOFF")" 2> $DIALOGOUT
  setConfig "START_DAAPD" "$(cat ${DIALOGOUT})"
}

function selectNoflushd
{
  START_NOFLUSHD=$(getConfig "START_NOFLUSHD")
  dialog --ok-label $(gettext "OK") --no-cancel --menu "$(gettext setup "selectNoflushd")" 10 30 2 ON "$(gettext setup "NoflushdON")" OFF "$(gettext setup "NoflushdOFF")" 2> $DIALOGOUT
  setConfig "START_NOFLUSHD" "$(cat ${DIALOGOUT})"
}

function selectRamdiskSize
{
  RAMDISK_SIZE=$(getConfig RAMDISK_SIZE)
  LRAMDISK_SIZE=$(dialog --inputbox "$(gettext setup "RAMDISK_SIZE")" 10 70 "${RAMDISK_SIZE:=4}" 2>&1)
  MaxRamdiskSizeMB=`echo "$(getRamsizeMB)/2" | bc`
  logger -t "setup.sh" "Max Ram: $MaxRamdiskSizeMB"
  logger -t "setup.sh" "iSelected Ramdisk Size: $LRAMDISK_SIZE"
  while [ $LRAMDISK_SIZE -gt $MaxRamdiskSizeMB ]; do
    dialog --msgbox "$(gettext setup "RAMDISK_SIZE_OVERFLOW") Max: $MaxRamdiskSizeMB MB" 10 70
    LRAMDISK_SIZE=$(dialog --inputbox "$(gettext setup "RAMDISK_SIZE")" 10 70 "${RAMDISK_SIZE:=4}" 2>&1)
  done
  setConfig "RAMDISK_SIZE" $LRAMDISK_SIZE
}

# ========================================================
# Sprachauswahl
function getLanguage()
{
  LC_ALL=$(getCOnfig "LC_ALL")
  dialog --ok-label $(gettext "OK") --no-cancel --menu "$(gettext setup "selectLanguage")" 10 30 2 de_DE "Deutsch" en_US "English" 2> $DIALOGOUT
  export LC_ALL=$(cat $DIALOGOUT)
  setConfig "LC_ALL" "${LC_ALL}"
}

function selectOverlay
{
  OVERLAY=$(getConfig "OVERLAY")
  if [ "x${ACTIVYFOUND}" != "xNO" ]; then
    dialog --ok-label "$(gettext OK)" --no-cancel --menu "$(gettext setup selectOverlay)" 14 70 8 ON "Overlay On" OFF "Overlay Off" 2>$DIALOGOUT
    case "$(cat $DIALOGOUT)" in
      ON)       setConfig "OVERLAY" "ON";;
      OFF)      setConfig "OVERLAY" "OFF";;
    esac
  else
    dialog --msgbox "$(gettext setup "NoOverlay")" 10 70
    setConfig "OVERLAY" "OFF"
  fi 
}

# ========================================================
# HD einrichten
function selectHD
{
  /bin/true  
}

# ========================================================
# CDRom einrichten
function selectCDRom
{
  CDROM=$(getConfig "CDROM")
  CMD="dialog --no-cancel --menu \"$(gettext setup selectCDRom)\" 20 70 10 "
  for cdrom in $(/usr/bin/getCDRom); do
    CMD="$CMD $cdrom \"$(gettext setup $cdrom)\" "
  done
  CMD="$CMD 2> $DIALOGOUT"
  echo "$CMD" >/tmp/CDCMD
  eval $CMD
  CDROM="/dev/$(cat $DIALOGOUT)"
  setConfig "CDROM" "${CDROM}"
  ln -sf ${CDROM} /dev/cdrom
}

# ========================================================
# IR einrichten
function selectIR
{
  REMOTE=$(getConfig "REMOTE")
  CMD="dialog --no-cancel --radiolist \"$(gettext setup selectIR)\" 20 70 10 "
  CMD="$CMD IRDVB \"$(gettext setup sIRDVB)\" $(checkSetting REMOTE DVB)"
  if [ $(checkOutput pvr350) -eq 1 ]; then
    CMD="$CMD IRPVR \"$(gettext setup sIRPVR)\" $(checkSetting REMOTE PVR)"
  fi
  CMD="$CMD LIRC \"$(gettext setup sIRLIRC)\" $(checkSetting REMOTE LIRC)"
  CMD="$CMD OTHER \"$(gettext setup sIROTHER)\" $(checkSetting REMOTE OTHER)"
  CMD="$CMD 2> $DIALOGOUT"
  eval $CMD
  case "$(cat $DIALOGOUT)" in
    IRDVB)	addPlugin "remote"
    		REMOTE="DVB"
    		REMOTEMODULE="evdev"
    		REMOTEPORT=""
		IOPORT=""
    		;;
    IRPVR)	REMOTE="PVR"
    		REMOTEMODULE="lirc_i2c"
    		REMOTEPORT=""
		IOPORT=""
    		;;
    LIRC)	removePlugin "remote"
       		REMOTE="LIRC"
       		selectLIRCPort
    		;;
    OTHER)	removePlugin "remote"
    		REMOTE="OTHER"
    		REMOTEMODULE=""
    		REMOTEPORT=""
		IOPORT=""
    		;;
  esac
  setConfig "REMOTE" "${REMOTE}"
  setConfig "REMOTEMODULE" "${REMOTEMODULE}"
  setConfig "REMOTEPORT" "${REMOTEPORT}"
   setConfig "IOPORT" "${IOPORT}"
}

function selectLIRCPort
{
  REMOTEMODULE=$(getConfig "REMOTEMODULE")
  REMOTEPORT=$(getConfig "REMOTEPORT")
  IOPORT=$(getConfig "IOPORT")
  dialog --no-cancel --radiolist "$(gettext setup selectLIRCPort)" 20 70 10 \
                 ttyS0 "$(gettext setup sLttyS0)" $(checkSetting "REMOTEPORT" "/dev/ttyS0") \
                 ttyS1 "$(gettext setup sLttyS1)" $(checkSetting "REMOTEPORT" "/dev/ttyS1") \
                 i2c "$(gettext setup sLi2c)" $(checkSetting "REMOTEPORT" "i2c") \
                 ATIUSB "$(gettext setup sLUSB)" $(checkSetting "REMOTEPORT" "usb") 2> $DIALOGOUT
  case "$(cat $DIALOGOUT)" in
    ttyS0)	REMOTEPORT="/dev/ttyS0"
    		REMOTEMODULE="lirc_serial"
		IOPORT="io=0x3f8 irq=4"
    		;;
    ttyS1)	REMOTEPORT="/dev/ttyS1"
    		REMOTEMODULE="lirc_serial"
		IOPORT="io=0x2f8 irq=3"
    		;;
    i2c)	REMOTEPORT=""
    		REMOTEMODULE="lirc_i2c"
		IOPORT=""
    		;;
    ATIUSB)	REMOTEPORT="usb"
    		REMOTEMODULE="lirc_atiusb"
		IOPORT=""
    		;;
   esac
   setConfig "REMOTEPORT" "${REMOTEPORT}"
   setConfig "REMOTEMODULE" "${REMOTEMODULE}"
   setConfig "IOPORT" "${IOPORT}"
}

# ========================================================
# Poweroff einrichten
function selectPoweroff
{
  POWEROFF=$(getConfig "POWEROFF")
  CMD="dialog --ok-label \"$(gettext OK)\" --no-cancel --radiolist \"$(gettext setup selectPoweroff)\" 14 70 8 "
  CMD="$CMD shutdown \"$(gettext setup sPshutdown)\" $(checkSetting "POWEROFF" "shutdown")"
  if [ $(getSTR) -gt 0 ]; then
    CMD="$CMD suspend2ram \"$(gettext setup sPs2r)\" $(checkSetting "POWEROFF" "SuspendToRam")"
  fi
  CMD="$CMD 2> $DIALOGOUT"
  echo "$CMD" > /tmp/CMD
  eval $CMD
  case "$(cat $DIALOGOUT)" in
    shutdown)		setConfig "POWEROFF" "shutdown"
    			;;
    suspend2ram)	setConfig "POWEROFF" "SuspendToRam"
    			;;
  esac
}

# ========================================================
# Output einrichten
function selectOutput
{
  OUTPUT=$(getConfig "OUTPUT")
  CMD="dialog --ok-label \"$(gettext OK)\" --no-cancel --radiolist \"$(gettext setup selectOutput)\" 14 70 8 "
  if [ $(checkOutput "dvb") -eq 1 ]; then
    CMD="$CMD DVB \"$(gettext setup sODVB)\" $(checkSetting "OUTPUT" "dvb")"
    CMD="$CMD FBTV \"$(gettext setup sOfbtv)\" $(checkSetting "OUTPUT" "fbtv")" 
  fi
  if [ $(checkOutput "pvr350") -eq 1 ]; then
    CMD="$CMD PVR-350 \"$(gettext setup sOPVR350)\" $(checkSetting "OUTPUT" "pvr350")"
  fi
  if [ $(checkOutput "dxr3") -eq 1 ]; then
    CMD="$CMD DXR3 \"$(gettext setup sODXR3)\" $(checkSetting "OUTPUT" "dxr3")" 
  fi
  if [ $(checkOutput "xine") -eq 1 ]; then
    CMD="$CMD XINE \"$(gettext setup sOXine)\" $(checkSetting "OUTPUT" "xine")"
  fi
  if [ $(checkOutput "softdevice") -eq 1 ]; then
    CMD="$CMD SOFTDEVICE \"$(gettext setup sOSoftdevice)\" $(checkSetting "OUTPUT" "softdevice")"
  fi
  if [ $(checkOutput "em84xx") -eq 1 ]; then
    CMD="$CMD EM84XX \"$(gettext setup sOem84xx)\" $(checkSetting "OUTPUT" "em84xx")" 
  fi
  CMD="$CMD HEADLESS \"$(gettext setup sOHeadless)\" $(checkSetting "OUTPUT" "headless")"
  CMD="$CMD 2> $DIALOGOUT"
  eval $CMD
  case "$(cat $DIALOGOUT)" in
    HEADLESS)	OUTPUT="headless"
    		;;
    DVB)	OUTPUT="dvb"
    		;;
    DXR3)	OUTPUT="dxr3"
    		;;
    EM84XX)	OUTPUT="em84xx"
		#if [ "x${ACTIVYFOUND}" == "xYES" ]; then
			selectOverlay
		#fi
    		;;
    FBTV)	OUTPUT="fbtv"
    		;;
    SOFTDEVICE)	OUTPUT="softdevice"
    		;;
    XINE)	OUTPUT="xine"
    		;;
  esac
  setConfig "OUTPUT" "${OUTPUT}"
}

function MenuNetwork
{
  NETWORK="$(getConfig "NETWORK")"
  IP="$(getConfig "IP")"
  CMD="dialog --no-cancel --menu \"$(gettext setup menuNetwork)\" 25 80 15 "
  CMD="${CMD} Network \"$(gettext setup mNNetwork)\" "
  if [ "x${NETWORK}" == "xYES" ]; then
    CMD="${CMD} DHCP \"$(gettext setup mNDHCP)\" "
    if [ "x${IP}" != "xAUTO" ]; then
      CMD="${CMD} IP \"$(gettext setup mNIP)\" "
      CMD="${CMD} Netmask \"$(gettext setup mNNetmask)\" "
      CMD="${CMD} Gateway \"$(gettext setup mNGateway)\" "
      CMD="${CMD} Nameserver \"$(gettext setup mNNameserver)\" "
      CMD="${CMD} Domain \"$(gettext setup mNDomain)\" "
    fi
    CMD="${CMD} Hostname \"$(gettext setup mNHostname)\" "
  fi
  CMD="${CMD} Exit \"$(gettext setup Exit)\" "
  CMD="${CMD} 2> $DIALOGOUT"
  eval ${CMD}
  case "$(cat $DIALOGOUT)" in
    Network)	selectNetwork
    		MenuNetwork;;
    DHCP)	selectDHCP
    		MenuNetwork;;
    IP)		getIP
    		MenuNetwork;;
    Netmask)	getNetmask
    		MenuNetwork;;
    Gateway)	getGateway
    		MenuNetwork;;
    Hostname)	getHostname
    		MenuNetwork;;
    Nameserver)	getNameserver
    		MenuNetwork;; 
    Domain)	getDomain
    		MenuNetwork;;
    Exit)	MenuHardware;;
  esac
}

# ========================================================
# Output einrichten
function selectNetwork
{
  NETWORK=$(getConfig "NETWORK")
  CMD="dialog --ok-label \"$(gettext OK)\" --no-cancel --radiolist \"$(gettext setup EnableNetwork)\" 14 70 8 "
  CMD="$CMD network \"$(gettext setup sNNetwork)\" $(checkSetting "NETWORK" "YES")"
  CMD="$CMD nonetwork \"$(gettext setup sNNoNetwork)\" $(checkSetting "NETWORK" "NO")"
  CMD="$CMD 2> $DIALOGOUT"
  echo "$CMD" > /tmp/CMD
  eval $CMD
  case "$(cat $DIALOGOUT)" in
    network)		setConfig "NETWORK" "YES"
    			;;
    nonetwork)		setConfig "NETWORK" "NO"
    			;;
  esac
}

function selectDHCP
{
dialog --yesno "$(gettext setup "EnableDHCP")" 10 70
if [ $? -eq 0 ]; then
  setConfig "IP" "AUTO"
  setConfig "NETMASK" "AUTO"
  setConfig "GATEWAY" "AUTO"
  setConfig "DOMAIN" "AUTO"
  setConfig "NAMESERVER" "AUTO"
else
  setConfig "IP" ""
  setConfig "NETMASK" ""
  setConfig "GATEWAY" ""
  setConfig "DOMAIN" ""
  setConfig "NAMESERVER" ""
fi
}

function getIP
{
  IP=$(getConfig "IP")
  IP=$(dialog --inputbox "$(gettext setup "IP")" 10 70 "${IP:=192.168.0.2}" 2>&1)
  setConfig "IP" "${IP}"
}

function getNetmask
{
  NETMASK=$(getConfig "NETMASK")
  NETMASK=$(dialog --inputbox "$(gettext setup "Netmask")" 10 70 "${NETMASK:=255.255.255.0}" 2>&1)
  setConfig "NETMASK" "${NETMASK}"
}

function getGateway
{
  GATEWAY=$(getConfig "GATEWAY")
  GATEWAY=$(dialog --inputbox "$(gettext setup "Gateway")" 10 70 "${GATEWAY:=192.168.0.1}" 2>&1)
  setConfig "GATEWAY" "${GATEWAY}"
}

function getHostname
{
  HOSTNAME=$(getConfig "HOSTNAME")
  HOSTNAME=$(dialog --inputbox "$(gettext setup "Hostname")" 10 70 "${HOSTNAME:=mahlzeit}" 2>&1)
  setConfig "HOSTNAME" "${HOSTNAME}"
  echo "${HOSTNAME}" > /etc/hostname
  hostname -s ${HOSTNAME}
}

function getDomain
{
  DOMAIN=$(getConfig DOMAIN)
  DOMAIN=$(dialog --inputbox "$(gettext setup "Domain")" 10 70 "${DOMAIN:=vdr.home}" 2>&1)
  setConfig "DOMAIN" "${DOMAIN}"
}

function getNameserver
{
  NAMESERVER=$(getConfig "NAMESERVER")
  NAMESERVER=$(dialog --inputbox "$(gettext setup "Nameserver")" 10 70 "${NAMESERVER:=192.168.0.1}" 2>&1)
  setConfig "NAMESERVER" "${NAMESERVER}"
}

function getNetworkModule
{
  NETMODULE=$(/usr/bin/getNetworkHardware | tail -n1)
  if [ -z $NETMODULE ]; then
    setConfig "NETWORK" "no"
    dialog --msgbox "$(gettext setup "NoNetworkModuleFound")" 10 70
  else
    setConfig "NETWORK" "yes"
    setConfig "NETMODULE" "${NETMODULE}"
  fi
}

# ========================================================
# Channelauswahl
function selectChannels()
{
  CMD=""
  CHANNELDIALOG=""
  if [ "${ACTIVYFOUND}" == "YES" ]; then
    dialog --msgbox "$(gettext setup ActivyPluginSelect)" 10 70
  fi
  dialog --infobox "$(gettext setup "ChannelSearch")" 5 70
  for CHANNEL in $(ls ${CHANNELDIR}/*); do
    CHANNELDIALOG="${CHANNELDIALOG} \"$(basename $CHANNEL)\" \"<-- \" $(isChannel $CHANNEL)"
  done
  
  CMD="dialog --ok-label \"$(gettext setup OK)\" --no-cancel --radiolist \"$(gettext setup selectChannel)\" 25 78 16 ${CHANNELDIALOG} 2> $DIALOGOUT"
  eval $CMD

  CHANNEL=$(cat $DIALOGOUT)
  if [ ! -z $CHANNEL ]; then
    rm -f ${VDRETCDIR}/channels.conf 2> /dev/null
    ln -s ${CHANNELDIR}/$(basename ${CHANNEL}) ${VDRETCDIR}/channels.conf
    export CHANNELSCONF="$(ls -l /etc/vdr/channels.conf | awk -F "-> " '{ print $2 }')"
  fi
}


# ========================================================
# Pluginauswahl
function selectPlugins()
{
  PLUGINLIST="$(getConfig "PLUGINLIST")"
  PLUGINDIALOG=""
  CMD=""
  if [ "${ACTIVYFOUND}" == "YES" ]; then
    dialog --msgbox "$(gettext setup ActivyPluginSelect)" 10 70
  fi
  dialog --infobox "$(gettext setup "Pluginsearch")" 5 70
  for PLUGIN in $(ls ${PLUGINDIR}/libvdr-*.${VDRVersion}); do
     TMPPLUGIN=$(basename $PLUGIN)
     TMPPLUGIN=${TMPPLUGIN#libvdr-*}
     PLUGIN=${TMPPLUGIN%.so*}  
     if [ "$(isBlocked ${PLUGIN})" -gt "0" ]; then
       PLUGINDIALOG="${PLUGINDIALOG} $PLUGIN \"$(gettext plugins $PLUGIN)\" $(isSelected $PLUGIN)"
     fi
  done
  
  CMD="dialog --ok-label \"$(gettext setup OK)\" --no-cancel --checklist \"$(gettext setup selectPlugins)\" 25 78 16 ${PLUGINDIALOG} 2> $DIALOGOUT"
  eval $CMD

  PLUGINLIST=$(sed s/\"//g < $DIALOGOUT)
  setConfig "PLUGINLIST" "${PLUGINLIST}"
}

# ======================================================
# Whle Syslogverhalten
function selectSyslog 
{
  SYSLOG="$(getConfig "SYSLOG")"
  dialog --no-cancel --radiolist "$(gettext setup "selectSyslog")" 10 80 5 \
        "messages" "$(gettext setup "SyslogMessages")" $(test "x${SYSLOG}" == "xmessages" && echo ON || echo OFF) \
	"logread" "$(gettext setup "SyslogLogread")" $(test "x${SYSLOG}" == "xlogread" && echo ON || echo OFF) 2> $DIALOGOUT
  setConfig "SYSLOG" "$(cat $DIALOGOUT)"
}

function selectVesa
{
  dialog --no-cancel --radiolist "$(gettext setup "selectVesamode") $VESAMODE" 10 80 5 \
        "0x000" "$(gettext setup "Vesa0x000")" $(isVesamode "0x000") \
        "0x311" "$(gettext setup "Vesa0x311")" $(isVesamode "0x311") \
        "0x314" "$(gettext setup "Vesa0x314")" $(isVesamode "0x314") \
        "0x317" "$(gettext setup "Vesa0x317")" $(isVesamode "0x317") \
	"0x31a" "$(gettext setup "Vesa0x31a")" $(isVesamode "0x31a") 2> $DIALOGOUT
  VESAMODE=$(cat $DIALOGOUT)
  sed -i s/vga=0x.../vga=${VESAMODE}/ /boot/grub/menu.lst
}

# ======================================================
# Whle Webfrontend
function selectWebfrontend() 
{
  dialog --no-cancel --menu "$(gettext setup "selectWebfrontend")" 10 80 5 \
	"None" "$(gettext setup "WEBNone")" \
	"XXV" "$(gettext setup "WEBXXV")" \
	"VDRAdmin" "$(gettext setup "WEBVDRAdmin")" \
	"Both" "$(gettext setup "WEBBoth")" 2> $DIALOGOUT
  setConfig "WEBFRONTEND" "$(cat $DIALOGOUT)"
}

# ======================================================
# FTP Start
function selectFTP
{
  START_FTPD="$(getConfig "START_FTPD")"
  dialog --yesno "$(gettext setup "EnableFTP")" 10 70
  if [ $? -eq 0 ]; then
    setConfig "START_FTPD" "yes"
  else
    setConfig "START_FTPD" "no"
  fi
}

# ======================================================
# Samba Start
function selectSamba
{
  START_SAMBA="$(getConfig "START_SAMBA")"
  dialog --yesno "$(gettext setup "EnableSamba")" 10 70
  if [ $? -eq 0 ]; then
    setConfig "START_SAMBA" "yes"
  else
    setConfig "START_SAMBA" "no"
  fi
}

# ======================================================
# Noad Start
function selectNoad
{
  NOADRUN="$(getConfig "NOADRUN")"
  dialog --yesno "$(gettext setup "EnableNoad")" 10 70
  if [ $? -eq 0 ]; then
    setConfig "NOADRUN" "YES"
  else
    setConfig "NOADRUN" "NO"
  fi
}
	
# ======================================================
# Hardware Menu
function MenuHardware
{
  CMD="dialog --no-cancel --menu \"$(gettext setup HardwareMenu)\" 25 80 20"
  CMD="$CMD Network \"$(gettext setup MNetwork)\""
  CMD="$CMD Output \"$(gettext setup MOutput)\""
  if [ "x${ACTIVYFOUND}" == "xYES" ]; then
    CMD="$CMD Overlay \"$(gettext setup MOverlay)\""
  fi
  CMD="$CMD IR \"$(gettext setup MIR)\""
  if [ "x$(getConfig "REMOTE")" == "xLIRC" ]; then
    CMD="$CMD LIRCPort \"$(gettext setup MSelectLIRCPort)\""
  fi
  CMD="$CMD SelectRemote \"$(gettext setup MSelectRemote)\""
  CMD="$CMD CDROM \"$(gettext setup MHCDDEVICE)\""
  CMD="$CMD Exit \"$(gettext setup Exit)\" 2> $DIALOGOUT"
  eval $CMD
  case $(cat $DIALOGOUT) in
    Network)	MenuNetwork
    		MenuHardware
  		;;
    Overlay)	selectOverlay
    		MenuHardware
  		;;
    Output)	selectOutput
    		MenuHardware
  		;;
    IR)		selectIR
    		MenuHardware
  		;;
    LIRCPort)	selectLIRCPort
    		MenuHardware
    	 	;;	
    SelectRemote)	select-remote
    			MenuHardware
    			;;
    CDROM)	selectCDRom
    		MenuHardware
  		;;
    HD)		selectHD
    		MenuHardware
  		;;
    Exit)	MainMenu
    		;;
  esac
}

# ======================================================
# Hardware Menu
function MenuSoftware
{
  dialog --no-cancel --menu "$(gettext setup SoftwareMenu)" 25 80 20\
  	Plugins "$(gettext setup MSPlugins)"\
  	Channels "$(gettext setup MSChannels)"\
  	Noad "$(gettext setup MSNoad)"\
  	Webfrontend "$(gettext setup MSWebfrontend)"\
  	Ramdisk "$(gettext setup MSRamdiskSize)"\
  	Samba "$(gettext setup MSSamba)"\
  	FTP "$(gettext setup MSFTP)"\
  	Poweroff "$(gettext setup MSPoweroff)"\
  	Syslog "$(gettext setup MSSyslog)"\
  	Noflushd "$(gettext setup MSNoflushd)"\
  	DAAPD "$(gettext setup MSDAAPD)"\
  	Vesa "$(gettext setup MSVesa)"\
  	Lang "$(gettext setup MSLang)"\
  	Exit "$(gettext setup Exit)" 2> $DIALOGOUT
  case "$(cat $DIALOGOUT)" in
    Plugins)		selectPlugins
    			MenuSoftware
  			;;
    Channels)		selectChannels
    			MenuSoftware
  			;;
    Noad)		selectNoad
    			MenuSoftware
    			;;
    Webfrontend)	selectWebfrontend
    			MenuSoftware
  			;;
    Ramdisk)		selectRamdiskSize
    			MenuSoftware
  			;;
    Poweroff)		selectPoweroff
    			MenuSoftware
  			;;
    Syslog)		selectSyslog
    			MenuSoftware
  			;;
    DAAPD)		selectDAAPD
    			MenuSoftware
  			;;
    Noflushd)		selectNoflushd
    			MenuSoftware
  			;;
    Samba)		selectSamba
    			MenuSoftware
  			;;
    FTP)		selectFTP
    			MenuSoftware
  			;;
    Vesa)		selectVesa
    			MenuSoftware
  			;;
    Lang)		getLanguage
    			MenuSoftware
    			;;
    Exit)		MainMenu
    			;;
  esac
}

# ======================================================
# Mahlzeit Menu
function MenuMahlzeit
{
  dialog --no-cancel --menu "$(gettext setup MahlzeitMenu)" 25 80 20 Update "$(gettext setup MMUpdate)" Backup "$(gettext setup MMBackup)" Exit "$(gettext setup Exit)" 2> $DIALOGOUT
  case "$(cat $DIALOGOUT)" in
    Backup)	MenuBackup
    		MenuMahlzeit
    		;;
    Update)	MenuUpdate
    		MenuMahlzeit
    		;;
    Exit)	MainMenu
    		;;
  esac
}

# ======================================================
# Update Menu
function MenuUpdate
{
  dialog --no-cancel --menu "$(gettext setup UpdateMenu)" 25 80 20 ONLINEUPDATE "$(gettext setup MUONLINE)" OFFLINEUPDATE "$(gettext setup MUOFFLINE)" Exit "$(gettext setup Exit)" 2> $DIALOGOUT
  case "$(cat $DIALOGOUT)" in
    ONLINEUPDATE)	touch /tmp/setup.dialog
		    	dialog ${DPARMS} --tailbox /tmp/setup.dialog 20 60 &
	    		DIALOG_PID=$!
    			linvdrupdater.sh -v2 2>&1 >> /tmp/setup.dialog
    			kill $DIALOG_PID
    			rm /tmp/setup.dialog
    			;;
    OFFLINEUPDATE)	touch /tmp/setup.dialog
		    	dialog ${DPARMS} --tailbox /tmp/setup.dialog 20 80 &
	    		DIALOG_PID=$!
    			linvdrupdater.sh -v2 2>&1 >> /tmp/setup.dialog
    			kill $DIALOG_PID
    			rm /tmp/setup.dialog
    			;;
    Exit)		MenuMahlzeit
    			;;
  esac
}

# ======================================================
# Backup Menu
function MenuBackup
{
  dialog --no-cancel --menu "$(gettext setup BackupMenu)" 25 80 20 ISO "$(gettext setup MBISO)" CD "$(gettext setup MBCD)" Exit "$(gettext setup Exit)" 2> $DIALOGOUT
  case "$(cat $DIALOGOUT)" in
    ISO)	touch /tmp/setup.dialog
    		dialog ${DPARMS} --tailbox /tmp/setup.dialog 15 60 &
    		DIALOG_PID=$!
    		#mylinvdr.sh -miso -oshell >> /tmp/setup.dialog
    		kill $DIALOG_PID
    		rm /tmp/setup.dialog
    		;;
    CD)	touch /tmp/setup.dialog
    		dialog ${DPARMS} --tailbox /tmp/setup.dialog 15 60 &
    		DIALOG_PID=$!
    		#mylinvdr.sh -mcd -oshell >> /tmp/setup.dialog
    		kill $DIALOG_PID
    		rm /tmp/setup.dialog
    		;;
    Exit)	MenuMahlzeit
    		;;
  esac
}

# ======================================================
# Main Menu
function MainMenu
{
  dialog --no-cancel --menu "$(gettext setup MainMenu)" 25 80 15 Hardware "$(gettext setup MHardware)" Software "$(gettext setup MSoftware)" Mahlzeit-ISO "$(gettext setup MMahlzeit)" Exit "$(gettext setup Exit)" 2> $DIALOGOUT
  case "$(cat $DIALOGOUT)" in
    Hardware)		MenuHardware
    			MainMenu
 			;;
    Software)		MenuSoftware
    			MainMenu
  			;;
    Mahlzeit-ISO)	MenuMahlzeit
    			MainMenu
  			;;
    Exit)		#saveSysconfig
    			clear
    			exit 0
    			;;
  esac
}

# ======================================================
# Funktionen durchlaufen
if [ -r /usr/bin/activysetup.sh ]; then
  . /usr/bin/activysetup.sh 
fi
if [ ! -e ${SYSCONFIG} ]; then
  resetToDefault
  getLanguage
  getCDRom
  selectNetwork
  NETWORK="$(getConfig "NETWORK")"
  if [ "x${NETWORK}" == "xYES" ]; then
    selectDHCP
    IP="$(getConfig "IP")"
    if [ "x${IP}" != "xAUTO" ]; then
      getIP
      getNetmask
      getGateway
      getHostname
      getNameserver
      getDomain  
    fi
  fi
  checkHardware
  if [ "x${OUTPUT}" == "xem84xx" ]; then
    selectOverlay
  fi
  if [ "x${OUTPUT}" != "xem84xx" ]; then
    selectOutput
  fi
  if [ "x${REMOTE}" != "xOTHER" ]; then
    selectIR
  fi
  selectPlugins
  selectChannels
  selectWebfrontend
  selectSamba
  selectFTP
  saveSysconfig
  clear
else
  checkHardware
  MainMenu
  saveSysconfig
fi
cleanUp

if [ -r /usr/bin/activyfb.sh ]; then
  . /usr/bin/activyfb.sh
fi
